@@ -11,6 +11,7 @@ import base64
 from typing import Optional, List
 import os
 import urllib3
+
 urllib3.disable_warnings()
 from opentelemetry.instrumentation.urllib3 import URLLib3Instrumentor
 
@@ -43,6 +44,11 @@ class ClientWrapper:
         project_file_path: Optional[str] = None,
         classification_rules: Optional[List[ClassificationRule]] = None,
         ignore_default_rules: Optional[bool] = False,
+        target_board: Optional[str] = None,
+        app_name: Optional[str] = None,
+        branch_name: Optional[str] = None,
+        build_number: Optional[str] = None,
+        store_results: bool = False,
         **_kwargs
     ) -> MapFileResponse:
         with open(map_file_path, "rb") as f:
@@ -53,6 +59,17 @@ class ClientWrapper:
                 base64_encoded_project_file = base64.b64encode(f.read()).decode("utf-8")
         if classification_rules is None:
             classification_rules = []
+        kwargs = dict(
+            target_board=target_board,
+            app_name=app_name,
+            branch_name=branch_name,
+            build_number=build_number,
+            store_results=store_results,
+        )
+        for key in list(kwargs.keys()):
+            if kwargs[key] is None:
+                kwargs.pop(key)
+
         map_file_request = MapFileRequest(
             map_file=base64_encoded_map_file,
             stack_name=stack_name,
@@ -60,6 +77,7 @@ class ClientWrapper:
             compiler=compiler,
             classification_rules=classification_rules,
             ignore_default_rules=ignore_default_rules,
+            **kwargs
         )
         if base64_encoded_project_file is not None:
             map_file_request.project_file = base64_encoded_project_file
